@@ -114,7 +114,8 @@ def run_upload_command(args, progress=sys.stdout.isatty()):
                                       keystore_url=args.keystore,
                                       store_key=args.store_key,
                                       verify=args.verify,
-                                      image_tool_path=args.image_tool_path):
+                                      image_tool_path=args.image_tool_path,
+                                      streaming=args.streaming):
 
                 if name == 'in_size':
                     report.send(('input size', format_byte_size(value)))
